pub enum ServiceType {
Service,
Application,
}Expand description
Service type
Variants
Service
A service that is run in the background and tracks the PID
Application
A service that does not run in the background and does not track PID